# 说明文档

## 一、协议

本项目是本人工具库代码的整理，采用 [GNU Lesser General Public License v3.0](https://choosealicense.com/licenses/lgpl-3.0/) 开源协议，您可以在 ```./LICENSE.txt``` 看到它。

您可以任意使用（含商业使用）本项目代码，但如果您在本工具库基础上做出了一些修改，这些修改应当被公开 —— 以便开发者们更好的使用它们。

### 第三方依赖

- 本项目依赖于 [**numpy**](https://github.com/numpy/numpy), 该仓库引用的协议是 [BSD 3-Clause License](https://opensource.org/license/BSD-3-Clause) ，您可以在 ```./licenses/LICENSE_BSD.txt``` 看到它。

- 本项目依赖于 [**opencv**](https://github.com/opencv/opencv), 该仓库引用的协议是 [Apache License 2.0](https://www.apache.org/licenses/LICENSE-2.0) ，您可以在 ```./licenses/LICENSE_APACHE.txt``` 看到它。

- 本项目依赖于 [**shapely**](https://github.com/shapely/shapely), 该仓库引用的协议是 [BSD 3-Clause License](https://opensource.org/license/BSD-3-Clause) ，您可以在 ```./licenses/LICENSE_BSD.txt``` 看到它。

## 二、结构

本项目主体代码在 ```./jassor/utils``` 目录下， 使用方式参考 ```./jassor/demo``` 下对应名字的 .py 文件。

## 三、内容

本项目代码可能涵盖深度学习框架与图像识别任务相关工具。

## 四、使用

您可以通过 ```pip install jassor``` 安装本工具库，并参考本项目 demo 部分的使用方式。

## 五、声明

本项目设计的工具基于本人实际需求产生，不保证全部情况下可靠，仅对 demo 示例用法负责。
